==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ColumnMovingSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { ColumnMovingSeparatorDescription } from "./ColumnMovingSeparatorDescription";
/**
 * @hidden
 */
export let ColumnMovingSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnMovingSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnMovingSeparatorDescriptionMetadata.a == null) {
                ColumnMovingSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnMovingSeparatorDescriptionMetadata.c(ColumnMovingSeparatorDescriptionMetadata.a);
            }
            if (a.j(ColumnMovingSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnMovingSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("SeparatorWidth", "Number:int");
            a.item("ActualOpacity", "Number:double");
            a.item("Opacity", "Number:double");
        }
        static d(a) {
            ColumnMovingSeparatorDescriptionMetadata.b(a);
            a.aa("ColumnMovingSeparator", () => new ColumnMovingSeparatorDescription());
            a.z("ColumnMovingSeparator", ColumnMovingSeparatorDescriptionMetadata.a);
        }
    }
    ColumnMovingSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnMovingSeparatorDescriptionMetadata, 'ColumnMovingSeparatorDescriptionMetadata');
    ColumnMovingSeparatorDescriptionMetadata.a = null;
    return ColumnMovingSeparatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnMovingSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { ColumnMovingSeparatorDescription } from "./ColumnMovingSeparatorDescription";
/**
 * @hidden
 */
export let ColumnMovingSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnMovingSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnMovingSeparatorDescriptionMetadata.a == null) {
                ColumnMovingSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnMovingSeparatorDescriptionMetadata.c(ColumnMovingSeparatorDescriptionMetadata.a);
            }
            if (a.k(ColumnMovingSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnMovingSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("SeparatorWidth", "Number:int");
            a.item("ActualOpacity", "Number:double");
            a.item("Opacity", "Number:double");
        }
        static d(a) {
            ColumnMovingSeparatorDescriptionMetadata.b(a);
            a.ac("ColumnMovingSeparator", () => new ColumnMovingSeparatorDescription());
            a.ab("ColumnMovingSeparator", ColumnMovingSeparatorDescriptionMetadata.a);
        }
    }
    ColumnMovingSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnMovingSeparatorDescriptionMetadata, 'ColumnMovingSeparatorDescriptionMetadata');
    ColumnMovingSeparatorDescriptionMetadata.a = null;
    return ColumnMovingSeparatorDescriptionMetadata;
})();
